using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;
using LIT.UploadBar;

namespace SimpleUploadBar
{
	/// <summary>
	/// Summary description for UploadProgressBar.
	/// </summary>
	public class UploadProgressBar : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.Label lblBytesTotal;
		protected System.Web.UI.WebControls.Label lblBytesRead;
		protected System.Web.UI.WebControls.Label lblPercentage;
		protected System.Web.UI.WebControls.Label lblFileName;
	
		private void Page_Load(object sender, System.EventArgs e)
		{
			// When the page loads, information must be obtained
			// about the upload. The upload is identified by the
			// variable 'UploadID' passed in on the query string.

			// Obtain the unique ID from the query string.
			string uniqueId;
			if (Request.QueryString["UploadID"] != null)
				uniqueId = Request.QueryString["UploadID"];
			else
			{
				CloseWindow();
				return;
			}

			// Variables which will be used to read/display the results
			string sourceFileName;
			int
				percentage,
				bytesRead,
				bytesTotal,
				timeToCompletion;

			double dataRate;

			bool completed;

			string[] fileNames;
			// Obtain the status for this upload
			UploadDetails.GetStatus(uniqueId, out sourceFileName, out bytesRead, out bytesTotal, out percentage, out completed, out fileNames, out timeToCompletion, out dataRate);
			if (sourceFileName == null)
				sourceFileName = "unknown";

			// If the upload is finished, close the window.			
			if (completed)	
			{
				UploadDetails.ClearProgress(uniqueId);
				CloseWindow();
				return;
			}

			lblBytesRead.Text = bytesRead.ToString();
			lblBytesTotal.Text = bytesTotal.ToString();
			lblFileName.Text = sourceFileName;
			lblPercentage.Text = percentage.ToString();

			// Schedule a reload in 1 second.
			ScheduleReload(uniqueId, 1);
		}

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

		/// <summary>
		/// Registers a script into the page which will cause it to close itself
		/// </summary>
		private void CloseWindow()
		{
			// Build up the script
			string script = "";
			script += "<script language=\"javascript\">\r\n";
			script += "<!--\r\n";
			script += "window.close();\r\n";
			script += "//-->\r\n";
			script += "</script>\r\n";

			// Place the script into the page
			RegisterClientScriptBlock("close", script);
		}

		// Schedules a reload of the page
		private void ScheduleReload(string uniqueId, int reloadSeconds)
		{
			// Build the client side script used to schedule a reload
			string script = "";
			script += "<script type=\"text/javascript\"><!--\r\n";
			string path = "UploadProgressBar.aspx?UploadID=" + uniqueId;
			script += "setTimeout(\"document.location.href = '" + path + "';\"," + reloadSeconds * 1000 + ");";
			script += "// -->\r\n";
			script += "</script>\r\n";

			// Place the script into the page
			RegisterStartupScript("reload", script);
		}
	}
}
